@@ -2,7 +2,7 @@
 """This is the "nester.py" module and it provides one function called print_lol() 
    which prints lists that may or may not include nested lists."""
 
-def print_lol(the_list, level):
+def print_lol(the_list, level=0):
     """This function takes one positional argument called "the_list", which 
         is any Python list (of - possibly - nested lists). Each data item in the 
         provided list is (recursively) printed to the screen on it’s own line."""
